@@ -31,6 +31,8 @@ public:
     };
 
 public:
+    CppCodeModelSettings();
+
     void fromSettings(Utils::QtcSettings *s);
     void toSettings(Utils::QtcSettings *s);
 
@@ -169,7 +171,6 @@ public:
     void setData(const Data &data);
     Data data() const { return m_data; }
 
-    QVersionNumber clangdVersion() const { return Utils::clangdVersion(clangdFilePath()); }
     Utils::FilePath clangdIncludePath() const;
     static Utils::FilePath clangdUserConfigFilePath();
 
@@ -212,4 +213,6 @@ private:
     bool m_blockIndexing = false;
 };
 
+CppCodeModelSettings &cppCodeModelSettings();
+
 } // namespace CppEditor
